import request from "@/utils/request"

// 待办数据查询 获取用户消息的待阅和已阅数量
export function messageNotifyCount(data) {
    return request.get({
        url: '/acc/message/notify/count',
        data
    })
}
// 获取用户审批的待办和已办数量
export function messageFlowCount(data) {
    return request.get({
        url: '/acc/message/flow/count',
        data
    })
}

// 常用服务 
export function getUserFavorite(data) {
    return request.post({
        url: '/acc/profile/favorite',
        data
    })
}

// 跑马灯列表
export function swiperList(data) {
    return request.post({
        url: '/api/swiperList',
        data
    })
}

// 日程提醒
export function stepData(data) {
    return request.post({
        url: '/api/stepData',
        data
    })
}

// 销售任务
export function salesTask(data) {
    return request.post({
        url: '/api/salesTask',
        data
    })
}



// 新闻公告
export function newsQueryList(data) {
    return request.post({
        url: '/api/newsQueryList',
        data
    })
}